@@ -24,8 +24,6 @@
 #include <glib.h>
 #include <libgnomevfs/gnome-vfs.h>
 
-gchar *om_dbus_get_dev          (const gchar *bda, GnomeVFSResult *result);
-void   om_dbus_disconnect_dev   (const gchar *dev);
 gchar *om_dbus_get_display_name (const gchar *bda, GnomeVFSResult *result);
 
 GList *om_dbus_get_dev_list   (void);
